@@ -168,7 +168,7 @@ experience_evil_pixbuf_scale_or_ref (GdkPixbuf * pixbuf, gboolean need_persisten
 		return pixbuf;
 	} else {
 #if USE_EVIL
-		if (gdk_pixbuf_major_version == 2 && gdk_pixbuf_minor_version >= 0 && gdk_pixbuf_major_version <= 10) {
+		if (gdk_pixbuf_major_version == 2 && gdk_pixbuf_major_version <= 10) {
 			/* EVIL codepath. */
 			
 			/* shortcut */
@@ -185,6 +185,7 @@ experience_evil_pixbuf_scale_or_ref (GdkPixbuf * pixbuf, gboolean need_persisten
 			
 			/* did we just need to get the subpixbuf? */
 			if (src->width == dest_width && src->height == dest_height) {
+				g_object_ref (subpixbuf);
 				return subpixbuf;
 			}
 			
@@ -207,6 +208,7 @@ experience_evil_pixbuf_scale_or_ref (GdkPixbuf * pixbuf, gboolean need_persisten
 					gdk_pixbuf_scale (subpixbuf, scaled_pixbuf, 0, 0, dest_width, dest_height,
 					                  0, 0, (float) dest_width / src->width, (float) dest_height / src->height,
 					                  interp_type);
+					g_object_ref (scaled_pixbuf);
 					return scaled_pixbuf;
 				}
 			}
@@ -216,7 +218,8 @@ experience_evil_pixbuf_scale_or_ref (GdkPixbuf * pixbuf, gboolean need_persisten
 			
 			subpixbuf = experience_create_subpixbuf (pixbuf, src->x, src->y, src->width, src->height);
 			if (need_persistent || must_scale) {
-				result = experience_pixbuf_scale_simple_or_ref (subpixbuf, dest_width, dest_height, interp_type);
+				/* can't just ref ... */
+				result = gdk_pixbuf_scale_simple (subpixbuf, dest_width, dest_height, interp_type);
 				g_object_unref (subpixbuf);
 				
 				return result;
@@ -565,12 +568,14 @@ experience_pixbuf_composite (eXperienceRenderContext * dest, GdkRectangle * dest
 			/* make dirty_region bigger ... */
 			if (dest->dirty_region != NULL)
 				gdk_region_union_with_rect (dest->dirty_region, &tmp_area);
+			g_object_unref (image);
 		} else {
 			image = get_image (interp_type, info, TRUE);
 			gdk_draw_pixbuf (dest->drawable, dest->clip_gc, image,
 			                 tmp_area.x - dest_area->x, tmp_area.y - dest_area->y,
 			                 tmp_area.x, tmp_area.y, tmp_area.width, tmp_area.height,
 			                 GDK_RGB_DITHER_NORMAL, 0, 0);
+			g_object_unref (image);
 		}
 	}
 }
